@@ -21,6 +21,9 @@
 #include "config.h"
 #endif
 
+#ifdef PLATFORM_OS_OSX
+#include "OSXHelpers.hh"
+#endif
 
 #include <cstring>
 #include <sstream>
