@@ -17,8 +17,6 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-static const char rcsid[] = "$Id: Text.cc 1478 2008-03-10 23:28:05Z rcaelers $";
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -58,7 +56,7 @@ Text::time_to_string(time_t time, bool display_units)
     {
       t[0] = 0;
     }
-  int hrs = time/3600;
+  int hrs = (int)time/3600;
   int min = (time / 60) % 60;
   int sec = time % 60;
 
