@@ -78,27 +78,18 @@ using namespace workrave;
 BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
                          BreakFlags break_flags,
                          GUIConfig::BlockMode mode) :
-#ifdef PLATFORM_OS_WIN32
-  /*
-    Windows will have a gtk toplevel window regardless of mode.
-    Hopefully this takes care of the phantom parent problem.
-    Also, the break window title now appears on the taskbar, and
-    it will show up in Windows Task Manager's application list.
-  */
-  Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
-#else
-  Gtk::Window(mode==GUIConfig::BLOCK_MODE_NONE
-              ? Gtk::WINDOW_TOPLEVEL
-              : Gtk::WINDOW_POPUP),
-#endif
+  Gtk::Window(Gtk::WINDOW_TOPLEVEL),
   block_mode(mode),
   break_flags(break_flags),
   frame(NULL),
   break_response(NULL),
+  break_id(break_id),
   gui(NULL),
   visible(false),
+  sysoper_model_columns(NULL),
   accel_added(false),
   accel_group(NULL),
+  lock_button(NULL),
   postpone_button(NULL),
   skip_button(NULL),
   sysoper_combobox(NULL)
@@ -110,7 +101,6 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
 #endif
 {
   TRACE_ENTER("BreakWindow::BreakWindow");
-  this->break_id = break_id;
 
   if (mode != GUIConfig::BLOCK_MODE_NONE)
     {
@@ -118,6 +108,17 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
       set_decorated(false);
       set_skip_taskbar_hint(true);
       set_skip_pager_hint(true);
+
+#ifdef HAVE_GTK3
+      if (GtkUtil::running_on_wayland())
+        {
+          set_app_paintable(true);
+          signal_draw().connect(sigc::mem_fun(*this, &BreakWindow::on_draw));
+          signal_screen_changed().connect(sigc::mem_fun(*this, &BreakWindow::on_screen_changed));
+          on_screen_changed(get_screen());
+          set_size_request(head.get_width(), head.get_height());
+        }
+#endif
     }
 
   // On W32, must be *before* realize, otherwise a border is drawn.
@@ -141,52 +142,8 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
       window->set_functions(Gdk::FUNC_MOVE);
     }
 
-  // trace window handles:
-  // FIXME: debug, remove later
-#if defined( PLATFORM_OS_WIN32 ) && defined( TRACING )
-  HWND _hwnd = (HWND) GDK_WINDOW_HWND(gtk_widget_get_window(Gtk::Widget::gobj()));
-  HWND _scope = (HWND) GDK_WINDOW_HWND(gtk_widget_get_window(GTK_WIDGET( this->gobj())));
-  HWND _hRoot = GetAncestor( _hwnd, GA_ROOT );
-  HWND _hParent = GetAncestor( _hwnd, GA_PARENT );
-  HWND _hDesktop = GetDesktopWindow();
-
-  TRACE_MSG("BreakWindow created" <<  hex << _hwnd << dec);
-  if (_hwnd != _scope)
-    {
-      TRACE_MSG("!!! Scope issue: " << hex << _scope << dec);
-    }
-
-  if (_hwnd != _hRoot)
-    {
-      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop << dec);
-      TRACE_MSG("!!! BreakWindow GA_ROOT: " << hex << _hRoot << dec);
-    }
-
-  if (_hParent != _hDesktop)
-    {
-      TRACE_MSG("GetDesktopWindow()" <<  hex << _hDesktop << dec);
-      TRACE_MSG("!!! PreludeWindow GA_PARENT: " << hex << _hParent << dec);
-
-      HWND _hTemp;
-      while( IsWindow( _hParent ) && _hParent != _hDesktop )
-        {
-          _hTemp = _hParent;
-          _hParent = GetAncestor( _hTemp, GA_PARENT );
-          HWND _hParent2 = (HWND)GetWindowLong( _hTemp, GWL_HWNDPARENT );
-          if( _hParent == _hTemp )
-            break;
-          TRACE_MSG("!!!" <<  hex << _hTemp << " GA_PARENT: " << hex << _hParent  << dec);
-          TRACE_MSG("!!!" <<  hex << _hTemp << " GWL_HWNDPARENT: " << hex << _hParent2  << dec);
-        }
-    }
-
-#endif
-
   this->head = head;
-  if (head.valid)
-    {
-      Gtk::Window::set_screen(head.screen);
-    }
+  Gtk::Window::set_screen(head.screen);
 
   bool initial_ignore_activity = false;
 
@@ -240,11 +197,12 @@ BreakWindow::init_gui()
           window_frame->add(*frame);
           frame->add(*gui);
 
-          if (block_mode == GUIConfig::BLOCK_MODE_ALL)
+          if (block_mode == GUIConfig::BLOCK_MODE_ALL && !GtkUtil::running_on_wayland())
             {
 #ifdef PLATFORM_OS_WIN32
               desktop_window = new DesktopWindow(head);
               add(*window_frame);
+
 #elif defined(PLATFORM_OS_UNIX)
               set_size_request(head.get_width(),
                                head.get_height());
@@ -263,7 +221,17 @@ BreakWindow::init_gui()
             }
           else
             {
-              add(*window_frame);
+              if (GtkUtil::running_on_wayland())
+                {
+                  Gtk::Alignment *align
+                    = Gtk::manage(new Gtk::Alignment(0.5, 0.5, 0.0, 0.0));
+                  align->add(*window_frame);
+                  add(*align);
+                }
+              else
+                {
+                  add(*window_frame);
+                }
             }
         }
 
@@ -714,7 +682,7 @@ BreakWindow::start()
   raise();
 
 #ifdef PLATFORM_OS_WIN32
-  if( force_focus_on_break_start && this->head.valid && ( this->head.count == 0 ) )
+  if( force_focus_on_break_start && ( this->head.count == 0 ) )
     {
       HWND hwnd = (HWND)GDK_WINDOW_HWND( Gtk::Widget::gobj()->window );
       bool focused = W32ForceFocus::ForceWindowFocus( hwnd );
@@ -804,8 +772,40 @@ BreakWindow::get_gdk_window()
   return get_window();
 }
 
-
 void
 BreakWindow::update_break_window()
 {
 }
+
+#ifdef HAVE_GTK3
+bool BreakWindow::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
+{
+  cr->save();
+  if (block_mode == GUIConfig::BLOCK_MODE_ALL)
+    {
+      cr->set_source_rgba(0, 0, 0, 0.95);
+    }
+  else
+    {
+      cr->set_source_rgba(0.1, 0.1, 0.1, 0.1);
+    }
+  cr->set_operator(Cairo::OPERATOR_SOURCE);
+  cr->paint();
+  cr->restore();
+ 
+  return Gtk::Window::on_draw(cr);
+}
+
+void BreakWindow::on_screen_changed(const Glib::RefPtr<Gdk::Screen>& previous_screen)
+{
+  (void) previous_screen;
+
+  const Glib::RefPtr<Gdk::Screen> screen = get_screen();
+  const Glib::RefPtr<Gdk::Visual> visual = screen->get_rgba_visual();
+
+  if (visual)
+    {
+      gtk_widget_set_visual(GTK_WIDGET(gobj()), visual->gobj());
+    }
+}
+#endif
