@@ -195,29 +195,32 @@ GUI::main()
 {
   TRACE_ENTER("GUI::main");
 
-  Glib::OptionContext option_ctx;
 
 #ifdef PLATFORM_OS_UNIX
   XInitThreads();
 #endif
-  
+
   if (!Glib::thread_supported())
-    Glib::thread_init();
-
-  Glib::OptionGroup *option_group = new Glib::OptionGroup(egg_sm_client_get_option_group());
-  option_ctx.add_group(*option_group);
+    {
+      Glib::thread_init();
+    }
 
+#ifdef HAVE_GTK3
+  app = Gtk::Application::create(argc, argv, "org.workrave.WorkraveApplication");
+  app->hold();
+#else
   Gtk::Main *kit = NULL;
   try
     {
-      kit = new Gtk::Main(argc, argv, option_ctx);
+      kit = new Gtk::Main(argc, argv);
     }
   catch (const Glib::OptionError &e)
     {
       std::cout << "Failed to initialize: " << e.what() << std::endl;
       exit(1);
     }
-  
+#endif
+
   init_core();
   init_nls();
   init_debug();
@@ -237,25 +240,29 @@ GUI::main()
 
   on_timer();
 
-  TRACE_MSG("Initialized. Entering event loop.");
-
-  // Enter the event loop
+#ifdef HAVE_GTK3
+  app->run();
+#else
   Gtk::Main::run();
+#endif
+
   System::clear();
-  cleanup_session();
+
   for (list<sigc::connection>::iterator i = event_connections.begin(); i != event_connections.end(); i++)
     {
       i->disconnect();
     }
-    
+
   delete main_window;
   main_window = NULL;
 
   delete applet_control;
   applet_control = NULL;
 
+#if !defined(HAVE_GTK3)
   delete kit;
-  
+#endif
+
   TRACE_EXIT();
 }
 
@@ -275,7 +282,12 @@ GUI::terminate()
 
   collect_garbage();
 
+#ifdef HAVE_GTK3
+  app->release();
+#else
   Gtk::Main::quit();
+#endif
+
   TRACE_EXIT();
 }
 
@@ -375,48 +387,10 @@ GUI::init_platform()
 }
 
 
-void
-GUI::session_quit_cb(EggSMClient *client, GUI *gui)
-{
-  (void) client;
-  (void) gui;
-
-  TRACE_ENTER("GUI::session_quit_cb");
-
-  CoreFactory::get_configurator()->save();
-  Gtk::Main::quit();
-
-  TRACE_EXIT();
-}
-
-
-void
-GUI::session_save_state_cb(EggSMClient *client, GKeyFile *key_file, GUI *gui)
-{
-  (void) client;
-  (void) key_file;
-  (void) gui;
-
-  CoreFactory::get_configurator()->save();
-}
-
 void
 GUI::init_session()
 {
   TRACE_ENTER("GUI::init_session");
-  EggSMClient *client = NULL;
-  client = egg_sm_client_get();
-  if (client)
-    {
-      g_signal_connect(client,
-                       "quit",
-                       G_CALLBACK(session_quit_cb),
-                       this);
-      g_signal_connect(client,
-                       "save-state",
-                       G_CALLBACK(session_save_state_cb),
-                       this);
-    }
 
   session = new Session();
   session->init();
@@ -424,26 +398,6 @@ GUI::init_session()
   TRACE_EXIT();
 }
 
-
-void
-GUI::cleanup_session()
-{
-  EggSMClient *client = NULL;
-
-  client = egg_sm_client_get();
-  if (client)
-    {
-      g_signal_handlers_disconnect_by_func(client,
-                                           (gpointer)G_CALLBACK(session_quit_cb),
-                                           this);
-      g_signal_handlers_disconnect_by_func(client,
-                                           (gpointer)G_CALLBACK(session_save_state_cb),
-                                           this);
-    }
-}
-
-
-
 //! Initializes messages hooks.
 void
 GUI::init_debug()
@@ -473,7 +427,7 @@ GUI::init_nls()
       g_setenv("LANGUAGE", language.c_str(), 1);
     }
 
-#  if !defined(HAVE_GNOME) && !defined(HAVE_GTK3)
+#  if !defined(HAVE_GTK3)
   gtk_set_locale();
 #  endif
   const char *locale_dir;
@@ -554,18 +508,6 @@ GUI::init_multihead()
   TRACE_ENTER("GUI::init_multihead");
 
   init_gtk_multihead();
-  if (num_heads == -1)
-    {
-      init_multihead_mem(1);
-
-      heads[0].valid = false;
-      heads[0].count = 0;
-      heads[0].geometry.set_width(gdk_screen_width());
-      heads[0].geometry.set_height(gdk_screen_height());
-      heads[0].geometry.set_x(0);
-      heads[0].geometry.set_y(0);
-    }
-
   init_multihead_desktop();
   TRACE_EXIT();
 }
@@ -643,23 +585,12 @@ void
 GUI::init_multihead_desktop()
 {
   TRACE_ENTER("GUI::init_multihead_desktop");
-  TRACE_MSG("gdk width x height " << gdk_screen_width() << " " << gdk_screen_height());
 
   int width = 0;
   int height = 0;
 
-  // Use head info to determine screen size. I hope this results
-  // in the same size as the gdk_screen_xxx....
   for (int i = 0; i < num_heads; i++)
     {
-      if (!heads[i].valid)
-        {
-          // Not all heads have valid geometry. Use gdk.
-          width = gdk_screen_width();
-          height = gdk_screen_height();
-          break;
-        }
-
       int w = heads[i].geometry.get_x() + heads[i].geometry.get_width();
       int h = heads[i].geometry.get_y() + heads[i].geometry.get_height();
 
@@ -685,7 +616,6 @@ GUI::init_multihead_desktop()
     }
 }
 
-
 void
 GUI::init_gtk_multihead()
 {
@@ -709,15 +639,6 @@ GUI::init_gtk_multihead()
             }
         }
 
-      for (int i = 0; i < num_screens; i++)
-        {
-          Glib::RefPtr<Gdk::Screen> screen = display->get_screen(i);
-          if (screen)
-            {
-              TRACE_MSG("num monitors on screen " << i << " = " << screen->get_n_monitors());
-            }
-        }
-
       init_multihead_mem(new_num_heads);
 
       int count = 0;
@@ -748,9 +669,7 @@ GUI::init_gtk_multihead()
                     {
                       heads[count].screen = screen;
                       heads[count].monitor = j;
-                      heads[count].valid = true;
                       heads[count].count = count;
-
                       heads[count].geometry = rect;
                       count++;
                     }
@@ -801,7 +720,7 @@ GUI::init_gui()
   event_connections.push_back(status_icon->signal_visibility_changed().connect(sigc::mem_fun(*this, &GUI::on_visibility_changed)));
 
   process_visibility();
-  
+
 #ifdef HAVE_DBUS
   DBus *dbus = CoreFactory::get_dbus();
 
@@ -833,7 +752,7 @@ GUI::init_dbus()
     {
 #ifdef HAVE_DBUS_GIO
       if (dbus->is_running("org.workrave.Workrave"))
-#else      
+#else
       dbus->register_service("org.workrave.Workrave");
       if (!dbus->is_owner())
 #endif
@@ -852,7 +771,7 @@ GUI::init_dbus()
 #ifdef HAVE_DBUS_GIO
           dbus->register_service("org.workrave.Workrave", this);
 #endif
-          
+
           extern void init_DBusGUI(DBus *dbus);
           init_DBusGUI(dbus);
         }
@@ -920,7 +839,7 @@ GUI::init_sound_player()
       sound_player = new SoundPlayer(); /* LEAK */
       sound_player->init();
     }
-  catch (Exception)
+  catch (Exception &)
     {
       TRACE_MSG("No sound");
     }
@@ -1058,7 +977,7 @@ GUI::create_break_window(BreakId break_id, BreakHint break_hint)
         }
     }
   else
-    { 
+    {
       if (ignorable)
         {
           break_flags |= BreakWindow::BREAK_FLAGS_POSTPONABLE;
