@@ -32,6 +32,10 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
+#ifdef GDK_WINDOWING_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
+
 #include "GUI.hh"
 #include "Util.hh"
 #include "GtkUtil.hh"
@@ -342,29 +346,22 @@ GtkUtil::center_window(Gtk::Window &window, HeadInfo &head)
 {
   TRACE_ENTER("GtkUtil::center_window");
 
-  if (head.valid)
-    {
-      Gtk::Requisition size;
+  Gtk::Requisition size;
 #ifdef HAVE_GTK3
-      Gtk::Requisition minsize;
-      window.get_preferred_size(minsize, size);
+  Gtk::Requisition minsize;
+  window.get_preferred_size(minsize, size);
 #else
-      window.size_request(size);
+  window.size_request(size);
 #endif
 
-      int x = head.geometry.get_x() + (head.geometry.get_width() - size.width) / 2;
-      int y = head.geometry.get_y() + (head.geometry.get_height() - size.height) / 2;
+  int x = head.geometry.get_x() + (head.geometry.get_width() - size.width) / 2;
+  int y = head.geometry.get_y() + (head.geometry.get_height() - size.height) / 2;
 
-      TRACE_MSG(head.geometry.get_x() << " "  << head.geometry.get_width() << " " << size.width);
-      TRACE_MSG(head.geometry.get_y() << " "  << head.geometry.get_height() << " " << size.height);
+  TRACE_MSG(head.geometry.get_x() << " "  << head.geometry.get_width() << " " << size.width);
+  TRACE_MSG(head.geometry.get_y() << " "  << head.geometry.get_height() << " " << size.height);
 
-      window.set_position(Gtk::WIN_POS_NONE);
-      window.move(x, y);
-    }
-  else
-    {
-      window.set_position(Gtk::WIN_POS_CENTER_ALWAYS);
-    }
+  window.set_position(Gtk::WIN_POS_NONE);
+  window.move(x, y);
   TRACE_EXIT();
 }
 
@@ -416,3 +413,14 @@ GtkWindow *GtkUtil::get_visible_tooltip_window()
     g_list_free( list );
     return func_retval;
 }
+
+bool
+GtkUtil::running_on_wayland()
+{
+#ifdef GDK_WINDOWING_WAYLAND
+  GdkDisplay* display = gdk_display_manager_get_default_display(gdk_display_manager_get());
+  return GDK_IS_WAYLAND_DISPLAY(display);
+#else
+  return false;
+#endif
+}
